# Observing the Sky

This package collects code and pedagogical snippets related to astronomical observations of the sky, particular with ground-based telescopes. It is being assembled in support of the University of Colorado Boulder course "ASTR3510: Observations and Instrumentation" starting in Fall 2022.

We hope you may find it useful!
